@@ -294,20 +294,20 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
  # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
  # For more info: https://github.com/yarnpkg/yarn/issues/683#issuecomment-346038525
-    yarn_cache=os.getenv('PWD','') + '/.yarn_cache/'
-    local('mkdir -p .yarn_cache/')
+    yarn_cache=os.getenv('PWD','') + '/.yarn_cache'
+    local('mkdir -p .yarn_cache')
     local('yarn config set cache-folder %s' % yarn_cache)
 
     with lcd(installPath):
 
     # ensure yarn installs all build tools
         local("pwd")
-        local('yarn --production=false --no-progress --non-interactive install')
+        local('yarn --production=false --no-progress --non-interactive install --cache-folder %s' % yarn_cache)
 
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('yarn build %s %s ' % (options, ngApp))
+            local('yarn build %s %s --cache-folder %s' % (options, ngApp, yarn_cache))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
